<div id="main_window">
<div id="novel_contents">
<div id="novel_color">

<div class="novel_title">{{ title }}</div>

<div id="novel_ex">
{{desc|safe}}
</div>

<div class="novel_sublist">
<ul>
{%- for dex in index %}
{%- if dex['type']==1 %}
<li class="chapter">{{dex['text']}}</li>
{%- elif dex['type']==2 %}
<li>
<a href="{{dex['part']}}.html">{{dex['text']}}</a>
<br />
<span class="kaikou">{{dex['time'].strftime('%Y/%m/%d/ %H:%M')}}</span>
</li>
{%- endif %}
{%- endfor %}
</ul>
</div><!--novel_sublist-->

</div><!-- /#novel_color -->
</div><!--novel_contents-->

<!-- フッタここから -->
<div class="upper"><a href="#top">▲ページの上部へ</a></div>
<div id="footer">
<div id="footernavi">
<p>
<a href="https://syosetu.com">小説家になろう</a>
|
<a href="https://kakuyomy.jp">カクヨム</a>
|
<a href="{{url}}">公式で読む</a>
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="14" type="text" />
<input value="検索" type="submit" />
</form>
</div><!--footernavi-->
</div><!--footer-->
<!-- フッタここまで -->
</div>
