<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<meta name="format-detection" content="telephone=no" />

<title>{{ title }}</title>

<link rel="shortcut icon" href="static/narou.ico" />
<link rel="icon" href="static/narou.ico" />
<link rel="apple-touch-icon-precomposed" href="static/apple-touch-icon-precomposed.png" />

<script src="static/combine.js"></script>
<!--
<link rel="stylesheet" type="text/css" href="static/novel_smpview.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="static/reset.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="static/kotei.css" media="screen,print" />
-->
</head>


<body>
<div id="pc">
{% include "index_body_pc.html" %}
</div>

<div id="sp">
{% include "index_body_mobile.html" %}
</div>

<script src="static/custom.js"></script>
</body>
</html>