<a id="pageBottom" href="#footer">↓</a>
<div id="main"></div>
<div class="contents1">
<a href="index.html" class="margin_r20">{{title}}</a>
</div><!--contents1-->

<div id="novel_contents">
<div id="novel_color">
<div class="novel_bn">
{%- if part!=1 %}
<a href="{{part-1}}.html">&lt;&lt;&nbsp;前へ</a>
{%- endif %}
{%- if part!=total %}
<a href="{{part+1}}.html">次へ&nbsp;&gt;&gt;</a>
{%- endif %}
</div><!--novel_bn-->

<div id="novel_no">{{part}}/{{total}}</div>
<p class="novel_subtitle">{{subtitle}}</p>

<div id="novel_honbun" class="novel_view">
{%- for i in range(0,lines) %}
<p id="L{{ i+1 }}">{{ contents[i] }}</p>
{%- endfor %}
</div>

<div class="novel_bn">
{%- if part!=1 %}
<a href="{{part-1}}.html">&lt;&lt;&nbsp;前へ</a>
{%- endif %}
{%- if part!=total %}
<a href="{{part+1}}.html">次へ&nbsp;&gt;&gt;</a>
{%- endif %}
<a href="index.html">目次</a>
</div>
</div></div>
<br>
<a id="pageTop" href="#main">↑</a>

<!-- フッタここから -->
<div id="footer">
<ul class="undernavi">
<li><a href="https://syosetu.com">小説家になろう</a></li>
<li><a href="https://syosetu.com/user/top">ホーム</a></li>
<li><a href="https://kakuyomu.jp">カクヨム</a></li>
<li><a href="https://kakuyomu.jp/my/antenna/works">ホーム</a></li>
<li><a href="{{url}}">公式で読む</a></li>
<li id="search">
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="21" type="text" />
<input value="検索" type="submit" />
</form>
</li>
</ul>
</div><!--footer-->
<!-- フッタここまで -->
