<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<title>{{title}}</title>
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="format-detection" content="telephone=no" />
{%- for s in style %}
<style id="{{ s }}">
{{ style[s] }}
</style>
{%- endfor %}
<script>
	window.onload=function(){
		for (var i=0;i<document.styleSheets.length;i++) {
			var ownerNode = document.styleSheets[i].ownerNode;
			if (!["reset","kotei","dark"].includes(ownerNode.id) && ownerNode.type=="") {
				document.styleSheets[i].disabled = true;
			}
		}
	}

</script>
</head>

<body>
<a id="pageBottom" href="#footer">↓</a>
<div id="main"></div>
<div class="contents1">
</div>
<div id="novel_contents">
<div id="novel_color">
<p class="novel_subtitle">{{title}}</p>

<div id="novel_honbun" class="novel_view">
{%- for i in range(0,lines) %}
<p id="L{{ i+1 }}">{{ contents[i] }}</p>
{%- endfor %}
</div>

</div></div>
<br>
<a id="pageTop" href="#main">↑</a>

<!-- フッタここから -->
<div id="footer">
<ul class="undernavi">
<li><a href="https://syosetu.com">小説家になろう</a></li>
<li><a href="https://kakuyomu.jp">カクヨム</a></li>
<li><a href="{{url}}">公式で読む</a></li>
<li id="search">
<form action="https://yomou.syosetu.com/search.php">
<input name="word" size="21" type="text" />
<input value="検索" type="submit" />
</form>
</li>
</ul>
</div><!--footer-->
<!-- フッタここまで -->
</body>
</html>
